# Tutorials

These are all rendered versions of the Jupyter lab notebooks available in the [docs/tutorial](
https://github.com/darikg/curvey/tree/main/docs/tutorial) folder of the main repo.

- [Introduction](introduction.ipynb)
    - Constructing a curve, plotting curves, sequences of curves

- [Shape structure dataset](shape_structure_dataset.ipynb)
    - Loading curves from the [2D Shape Structure Dataset](https://2dshapesstructure.github.io/index.html)

- [Flow](flow.ipynb)
    - Curve shortening flow, singularity free curvature flow, Willmore flow

- [Blend](blend.ipynb)
    - Linear blending, curvature blending
